==> xlniuxdata-coin-1.0.2-20160516.104350-1-sources.jar: com/xunlei/niux/data/coin/dao/CoinTransDaoImpl.java <==
package com.xunlei.niux.data.coin.dao;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import com.ferret.common.dao.BaseDaoImpl;
import com.ferret.common.dao.util.DaoUtil;
import com.ferret.common.dao.vo.Page;
import com.xunlei.niux.data.coin.constant.CoinConstant;
import com.xunlei.niux.data.coin.util.SqlUtil;
import com.xunlei.niux.data.coin.vo.CoinTrans;

public class CoinTransDaoImpl extends BaseDaoImpl implements CoinTransDao{
	
	private static final Pattern INTERVAL_PATTERN =  Pattern.compile("^(-)?\\d\\s[A-Za-z_]+$");

	public void insert(final CoinTrans coinTrans) {
		StringBuilder sb=new StringBuilder();
		sb.append("insert into ").append(getTableName(coinTrans.getUserId()))
		  .append("(userId,userName,transDirect,transTime,transNum,transNo,remark,bizNo,transIp,balanceDate,actNo,gameId)")
		  .append(" values(?,?,?,?,?,?,?,?,?,?,?,?)");
		List<Object> paramList=new ArrayList<Object>();
		paramList.add(coinTrans.getUserId());
		paramList.add(coinTrans.getUserName());
		paramList.add(coinTrans.getTransDirect());
		paramList.add(coinTrans.getTransTime());
		paramList.add(coinTrans.getTransNum());
		paramList.add(coinTrans.getTransNo());
		paramList.add(coinTrans.getRemark());
		paramList.add(coinTrans.getBizNo());
		paramList.add(coinTrans.getTransIp());
		paramList.add(coinTrans.getBalanceDate());
		paramList.add(coinTrans.getActNo());
		paramList.add(coinTrans.getGameId());
		this.execute(sb.toString(), paramList);
	}
	public List<CoinTrans> find(final CoinTrans coinTrans, final Page page) {
		List<Object> paramList=new ArrayList<Object>();
		StringBuilder sb=new StringBuilder();
		sb.append("select * from ").append(getTableName(coinTrans.getUserId())).append(DaoUtil.createWhere(coinTrans, paramList))
		  .append(SqlUtil.createOrder(CoinTrans.class, page)).append(SqlUtil.createLimit(page));
		return this.executeQuery(CoinTrans.class, sb.toString(), paramList);
	}

	public int count(final String userId, final CoinTrans coinTrans) {
		List<Object> paramList=new ArrayList<Object>();
		StringBuilder sb=new StringBuilder();
		sb.append("select count(*) from ").append(getTableName(userId)).append(DaoUtil.createWhere(coinTrans, paramList));
		return this.getJdbcTemplate().queryForInt(sb.toString(), paramList.toArray());
	}
	@Override
	public List<CoinTrans> find(final CoinTrans coinTrans, final String actNoArr,final Page page) {
		List<Object> paramList=new ArrayList<Object>();
		StringBuilder sb=new StringBuilder();
		sb.append("select * from ").append(getTableName(coinTrans.getUserId())).append(DaoUtil.createWhere(coinTrans, paramList))
		.append(" and actno in  ("+actNoArr+")" )
		.append(SqlUtil.createOrder(CoinTrans.class, page)).append(SqlUtil.createLimit(page));
		return this.executeQuery(CoinTrans.class, sb.toString(), paramList);
	}
	@Override
	public int count(final String userId, final String actNoArr,final CoinTrans coinTrans) {
		List<Object> paramList=new ArrayList<Object>();
		StringBuilder sb=new StringBuilder();
		sb.append("select count(*) from ").append(getTableName(userId)).append(DaoUtil.createWhere(coinTrans, paramList)).append(" and actno in  ("+actNoArr+")" );
		return this.getJdbcTemplate().queryForInt(sb.toString(), paramList.toArray());
	}
	/**
	 * 获取表名，按照hash值分50张分表
	 * @param userId
	 * @return
	 */
	private String getTableName(final String userId){
		if(userId==null||"".equals(userId)){
			throw new RuntimeException("userId为空");
		}
		long xunleiId=Long.valueOf(userId);
		return "cointrans_"+(xunleiId%50);
	}
	
	@Override
	public List<CoinTrans> findDateSub(final String userId, final String expr,
			final Page page) {
		List<Object> paramList=new ArrayList<Object>();
		paramList.add(userId);
		
		//正则表达式验证符合 "9 DAY"等格式
		if(INTERVAL_PATTERN != null){
			Matcher matcher = INTERVAL_PATTERN.matcher(expr);
			if(!matcher.matches()){
				return null;
			}
		}
		
		StringBuilder sb=new StringBuilder();
		sb.append("select * from ")
			.append(getTableName(userId))
			.append(" where userid = ? ")
			.append(" AND DATE_FORMAT(transTime,'%Y-%m-%d') >= DATE_SUB(CURRENT_DATE(),INTERVAL  "+expr+" ) ")
			.append(SqlUtil.createOrder(CoinTrans.class, page)).append(SqlUtil.createLimit(page));
		return this.executeQuery(CoinTrans.class, sb.toString(), paramList);
	}
	
	@Override
	public List<CoinTrans> findPeriod(final String userId, final String startTime,
			final String endTime, final Page page) {
		return findPeriod(userId, startTime, endTime, null, page);
	}
	
	@Override
	public List<CoinTrans> findPeriod(final String userId, final String startTime,
			final String endTime, final String transDirect, final Page page) {
		List<Object> paramList=new ArrayList<Object>();
		paramList.add(userId);
		
		StringBuilder sb=new StringBuilder();
		sb.append("select * from ")
			.append(getTableName(userId))
			.append(" where userid = ? ");
		if(transDirect != null) {
			sb.append(" AND transDirect = ? ");
			paramList.add(transDirect);
		}
		
		sb.append(" AND DATE_FORMAT(transTime,'%Y-%m-%d') >= DATE_FORMAT(?,'%Y-%m-%d') ")
			.append(" AND DATE_FORMAT(transTime,'%Y-%m-%d') <= DATE_FORMAT(?,'%Y-%m-%d') ")
			.append(SqlUtil.createOrder(CoinTrans.class, page)).append(SqlUtil.createLimit(page));
		
		paramList.add(startTime);
		paramList.add(endTime);
		
		return this.executeQuery(CoinTrans.class, sb.toString(), paramList);
	}
	
	@Override
	public Integer getTodayCoin(String userId){
		StringBuilder sb =new StringBuilder();
		sb.append("select sum(transNum) from " + getTableName(userId));
		sb.append(" where transDirect=? and balanceDate=? and userId=?");
		
		SimpleDateFormat simpleDateFormat=new SimpleDateFormat("yyyy-MM-dd");
		String dateStr = simpleDateFormat.format(new Date());
		
		Object[] args = new Object[3];
		args[0] = CoinConstant.COIN_TRANSDIRECT_RECHARGE;
		args[1] = dateStr;
		args[2] = userId;
		        
		Integer todayCoin = this.getJdbcTemplate().queryForInt(sb.toString(), args);
		
		return todayCoin;
		
	}
	
	@Override
	public int countPeriod(String userId, String startTime, String endTime) {
		return countPeriod(userId, startTime, endTime, null);
	}
	
	@Override
	public int countPeriod(String userId, String startTime, String endTime,
			String transDirect) {
		List<Object> paramList=new ArrayList<Object>();
		paramList.add(userId);
		
		StringBuilder sb = new StringBuilder();
		sb.append("select count(seqId) from ")
			.append(getTableName(userId))
			.append(" where userid = ? ");
			
		if(transDirect != null) {
			sb.append(" AND transDirect = ? ");
			paramList.add(transDirect);
		}
		
		sb.append(" AND DATE_FORMAT(transTime,'%Y-%m-%d') >= DATE_FORMAT(?,'%Y-%m-%d') ")
			.append(" AND DATE_FORMAT(transTime,'%Y-%m-%d') <= DATE_FORMAT(?,'%Y-%m-%d') ");
		
		paramList.add(startTime);
		paramList.add(endTime);
		
		return this.getJdbcTemplate().queryForInt(sb.toString(), paramList.toArray());
	}
}

==> xlniuxdata-coin-1.0.11-sources.jar: com/xunlei/niux/data/coin/dao/CoinTransDaoImpl.java <==
package com.xunlei.niux.data.coin.dao;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.ferret.common.dao.BaseDaoImpl;
import com.ferret.common.dao.util.DaoUtil;
import com.ferret.common.dao.vo.Page;
import com.xunlei.niux.data.coin.constant.CoinConstant;
import com.xunlei.niux.data.coin.constant.SqlLock;
import com.xunlei.niux.data.coin.util.SqlUtil;
import com.xunlei.niux.data.coin.vo.CoinTrans;

public class CoinTransDaoImpl extends BaseDaoImpl implements CoinTransDao{

	private static Logger logger = LoggerFactory.getLogger(CoinTransDaoImpl.class.getName());
	private static final Pattern INTERVAL_PATTERN =  Pattern.compile("^(-)?\\d\\s[A-Za-z_]+$");

	public void insert(final CoinTrans coinTrans) {
		StringBuilder sb=new StringBuilder();
		sb.append("insert into ").append(getTableName(coinTrans.getUserId()))
		  .append("(userId,userName,transDirect,transTime,transNum,transNo,remark,bizNo,transIp,balanceDate,actNo,gameId,leftNum,originTransNo,expireTime,transStatus)")
		  .append(" values(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
		List<Object> paramList=new ArrayList<Object>();
		paramList.add(coinTrans.getUserId());
		paramList.add(coinTrans.getUserName());
		paramList.add(coinTrans.getTransDirect());
		paramList.add(coinTrans.getTransTime());
		paramList.add(coinTrans.getTransNum());
		paramList.add(coinTrans.getTransNo());
		paramList.add(coinTrans.getRemark());
		paramList.add(coinTrans.getBizNo());
		paramList.add(coinTrans.getTransIp());
		paramList.add(coinTrans.getBalanceDate());
		paramList.add(coinTrans.getActNo());
		paramList.add(coinTrans.getGameId());
		paramList.add(coinTrans.getLeftNum());
		paramList.add(coinTrans.getOriginTransNo());
		paramList.add(coinTrans.getExpireTime());
		paramList.add(coinTrans.getTransStatus());
		this.execute(sb.toString(), paramList);
	}
	public List<CoinTrans> find(final CoinTrans coinTrans, final Page page) {
		List<Object> paramList=new ArrayList<Object>();
		StringBuilder sb=new StringBuilder();
		sb.append("select * from ").append(getTableName(coinTrans.getUserId())).append(DaoUtil.createWhere(coinTrans, paramList))
		  .append(SqlUtil.createOrder(CoinTrans.class, page)).append(SqlUtil.createLimit(page));
		return this.executeQuery(CoinTrans.class, sb.toString(), paramList);
	}

	public int count(final String userId, final CoinTrans coinTrans) {
		List<Object> paramList=new ArrayList<Object>();
		StringBuilder sb=new StringBuilder();
		sb.append("select count(*) from ").append(getTableName(userId)).append(DaoUtil.createWhere(coinTrans, paramList));
		return this.getJdbcTemplate().queryForInt(sb.toString(), paramList.toArray());
	}
	@Override
	public List<CoinTrans> find(final CoinTrans coinTrans, final String actNoArr,final Page page) {
		List<Object> paramList=new ArrayList<Object>();
		StringBuilder sb=new StringBuilder();
		sb.append("select * from ").append(getTableName(coinTrans.getUserId())).append(DaoUtil.createWhere(coinTrans, paramList))
		.append(" and actno in  ("+actNoArr+")" )
		.append(SqlUtil.createOrder(CoinTrans.class, page)).append(SqlUtil.createLimit(page));
		return this.executeQuery(CoinTrans.class, sb.toString(), paramList);
	}
	@Override
	public int count(final String userId, final String actNoArr,final CoinTrans coinTrans) {
		List<Object> paramList=new ArrayList<Object>();
		StringBuilder sb=new StringBuilder();
		sb.append("select count(*) from ").append(getTableName(userId)).append(DaoUtil.createWhere(coinTrans, paramList)).append(" and actno in  ("+actNoArr+")" );
		return this.getJdbcTemplate().queryForInt(sb.toString(), paramList.toArray());
	}
	/**
	 * 获取表名，按照hash值分50张分表
	 * @param userId
	 * @return
	 */
	private String getTableName(final String userId){
		if(userId==null||"".equals(userId)){
			throw new RuntimeException("userId为空");
		}
		long xunleiId=Long.valueOf(userId);
		return "cointrans_"+(xunleiId%50);
	}
	
	@Override
	public List<CoinTrans> findDateSub(final String userId, final String expr,
			final Page page) {
		List<Object> paramList=new ArrayList<Object>();
		paramList.add(userId);
		
		//正则表达式验证符合 "9 DAY"等格式
		if(INTERVAL_PATTERN != null){
			Matcher matcher = INTERVAL_PATTERN.matcher(expr);
			if(!matcher.matches()){
				return null;
			}
		}
		
		StringBuilder sb=new StringBuilder();
		sb.append("select * from ")
			.append(getTableName(userId))
			.append(" where userid = ? ")
			.append(" AND DATE_FORMAT(transTime,'%Y-%m-%d') >= DATE_SUB(CURRENT_DATE(),INTERVAL  "+expr+" ) ")
			.append(SqlUtil.createOrder(CoinTrans.class, page)).append(SqlUtil.createLimit(page));
		return this.executeQuery(CoinTrans.class, sb.toString(), paramList);
	}
	
	@Override
	public List<CoinTrans> findPeriod(final String userId, final String startTime,
			final String endTime, final Page page) {
		return findPeriod(userId, startTime, endTime, null, page);
	}
	
	@Override
	public List<CoinTrans> findPeriod(final String userId, final String startTime,
			final String endTime, final String transDirect, final Page page) {
		List<Object> paramList=new ArrayList<Object>();
		paramList.add(userId);
		
		StringBuilder sb=new StringBuilder();
		sb.append("select * from ")
			.append(getTableName(userId))
			.append(" where userid = ? ");
		if(transDirect != null) {
			sb.append(" AND transDirect = ? ");
			paramList.add(transDirect);
		}
		
		sb.append(" AND DATE_FORMAT(transTime,'%Y-%m-%d') >= DATE_FORMAT(?,'%Y-%m-%d') ")
			.append(" AND DATE_FORMAT(transTime,'%Y-%m-%d') <= DATE_FORMAT(?,'%Y-%m-%d') ")
			.append(SqlUtil.createOrder(CoinTrans.class, page)).append(SqlUtil.createLimit(page));
		
		paramList.add(startTime);
		paramList.add(endTime);
		
		return this.executeQuery(CoinTrans.class, sb.toString(), paramList);
	}
	
	@Override
	public Integer getTodayCoin(String userId){
		StringBuilder sb =new StringBuilder();
		sb.append("select sum(transNum) from " + getTableName(userId));
		sb.append(" where transDirect=? and balanceDate=? and userId=?");
		
		SimpleDateFormat simpleDateFormat=new SimpleDateFormat("yyyy-MM-dd");
		String dateStr = simpleDateFormat.format(new Date());
		
		Object[] args = new Object[3];
		args[0] = CoinConstant.COIN_TRANSDIRECT_RECHARGE;
		args[1] = dateStr;
		args[2] = userId;
		        
		Integer todayCoin = this.getJdbcTemplate().queryForInt(sb.toString(), args);
		
		return todayCoin;
		
	}
	
	@Override
	public int countPeriod(String userId, String startTime, String endTime) {
		return countPeriod(userId, startTime, endTime, null);
	}
	
	@Override
	public int countPeriod(String userId, String startTime, String endTime,
			String transDirect) {
		List<Object> paramList=new ArrayList<Object>();
		paramList.add(userId);
		
		StringBuilder sb = new StringBuilder();
		sb.append("select count(seqId) from ")
			.append(getTableName(userId))
			.append(" where userid = ? ");
			
		if(transDirect != null) {
			sb.append(" AND transDirect = ? ");
			paramList.add(transDirect);
		}
		
		sb.append(" AND DATE_FORMAT(transTime,'%Y-%m-%d') >= DATE_FORMAT(?,'%Y-%m-%d') ")
			.append(" AND DATE_FORMAT(transTime,'%Y-%m-%d') <= DATE_FORMAT(?,'%Y-%m-%d') ");
		
		paramList.add(startTime);
		paramList.add(endTime);
		
		return this.getJdbcTemplate().queryForInt(sb.toString(), paramList.toArray());
	}
	@Override
	public List<CoinTrans> findPeriodexpireTime(String userId,
			String startTime, String endTime, String transDirect, Page page, SqlLock lock) {
		List<Object> paramList=new ArrayList<Object>();
		paramList.add(userId);
		
		StringBuilder sb=new StringBuilder();
		sb.append("select * from ")
			.append(getTableName(userId))
			.append(" where userid = ? and leftNum != 0 and transStatus = 0 ");
		if(transDirect != null) {
			sb.append(" AND transDirect = ? ");
			paramList.add(transDirect);
		}
		
		sb.append(" AND DATE_FORMAT(expireTime,'%Y-%m-%d') >= DATE_FORMAT(?,'%Y-%m-%d') ")
			.append(" AND DATE_FORMAT(expireTime,'%Y-%m-%d') <= DATE_FORMAT(?,'%Y-%m-%d') ")
			.append(SqlUtil.createOrder(CoinTrans.class, page)).append(SqlUtil.createLimit(page)).append(SqlUtil.getLockStr(lock));
		
		paramList.add(startTime);
		paramList.add(endTime);
		
		return this.executeQuery(CoinTrans.class, sb.toString(), paramList);
	}
	@Override
	public int[] commitAll(final List<CoinTrans> insertList,
			List<CoinTrans> updateList) {
		List<String> sqls = new ArrayList<String>();
		String[] sql = new String[insertList.size() + updateList.size()];
		
		StringBuilder sb = new StringBuilder();

		
		//生成插入数据
		for(CoinTrans coinTrans : insertList){
			sb.delete(0, sb.length());//清空数据
			sb.append("insert into ").append(getTableName(coinTrans.getUserId()))
			  .append(" (userId,userName,transDirect,transTime,transNum,transNo,remark,bizNo,transIp,balanceDate,actNo,gameId,leftNum,originTransNo,expireTime,transStatus)")
			  .append(" values('"+coinTrans.getUserId()+"','"+coinTrans.getUserName()+"','"+coinTrans.getTransDirect()
					  +"','"+coinTrans.getTransTime()+"',"+coinTrans.getTransNum()+",'"+coinTrans.getTransNo()+"','"+coinTrans.getRemark()
					  +"','"+coinTrans.getBizNo()+"','"+coinTrans.getTransIp()+"','"+coinTrans.getBalanceDate()+"','"+coinTrans.getActNo()
					  +"','"+coinTrans.getGameId()+"',"+coinTrans.getLeftNum()+",'"+coinTrans.getOriginTransNo()+"','"+coinTrans.getExpireTime()
					  +"',"+coinTrans.getTransStatus()+") ");
			
			sqls.add(sb.toString());
		}

		//生成更新数据
		for(CoinTrans coinTrans : updateList){
			sb.delete(0, sb.length());
			sb.append("update ").append(getTableName(coinTrans.getUserId()))
			  .append(" set leftNum = "+coinTrans.getLeftNum()+",originTransNo = '"+coinTrans.getOriginTransNo()
					  +"',expireTime = '"+coinTrans.getExpireTime()+"',transStatus = "+coinTrans.getTransStatus()
					  +" where userId = '"+coinTrans.getUserId()+"' and transDirect = '"+coinTrans.getTransDirect()
					  +"' and bizNo = '"+coinTrans.getBizNo()
					  +"' and transNo = '"+coinTrans.getTransNo()+"'");
			
			sqls.add(sb.toString());
		}
		
		sqls.toArray(sql);
		logger.info("commitAll sqls:"+sqls);
		return this.getJdbcTemplate().batchUpdate(sql);

	}
}
